@@ -61,6 +61,7 @@ int main (int argc, char *argv[])
     aboutdata.addAuthor(ki18n("Paul Giannaros"), ki18n("Contributor"), "ceruleanblaze@gmail.com");
     aboutdata.addCredit(ki18n("Jorge Luis Arzola"), ki18n("Testing"), "arzolacub@hotmail.com");
     aboutdata.addCredit(ki18n("David Powell"), ki18n("Testing"), "achiestdragon@gmail.com");
+    aboutdata.setProgramIconName("preferences-desktop-text-to-speech");
 
     KCmdLineArgs::init( argc, argv, &aboutdata );
 
@@ -78,7 +79,7 @@ int main (int argc, char *argv[])
     KUniqueApplication::setOrganizationDomain("kde.org");
     KUniqueApplication::setApplicationName("KttsMgr");
     KUniqueApplication app;
-
+    app.setQuitOnLastWindowClosed( false );
     if(!KUniqueApplication::start())
     {
         kDebug() << "kttsmgr is already running";
@@ -104,9 +105,6 @@ KttsMgrTray::KttsMgrTray(QWidget *parent):
 {
     setObjectName("kttsmgrsystemtray");
 
-//    QIcon icon = KIconLoader::global()->loadIcon("preferences-desktop-text-to-speech", KIconLoader::Small);
-//    setIcon (icon);
-
     // Start KTTS daemon if enabled and if not already running.
     KConfig _config( "kttsdrc" );
     KConfigGroup config(&_config, "General");
@@ -168,8 +166,8 @@ bool KttsMgrTray::event(QEvent *event)
     // To make it work on all platforms, would have to constantly monitor status and update,
     // which would suck up huge amounts of CPU.
     if (event->type() == QEvent::ToolTip) {
-        QString status = "<qt><b>KTTSMgr</b> - ";
-        status += i18n("<qt>Text-to-Speech Manager");
+        QString status = "<qt><b>KTTSMgr</b> - <qt>";
+        status += i18n("Text-to-Speech Manager");
         status += "<br /><br />";
         status += getStatus();
         status += "</qt>";
@@ -244,11 +242,11 @@ QString KttsMgrTray::stateToStr(int state)
     switch( state )
     {
         case KSpeech::jsQueued: return        i18n("Queued");
-        case KSpeech::jsSpeakable: return     i18n("Waiting");
+        case KSpeech::jsSpeakable: return     i18nc("Waiting for an action", "Waiting");
         case KSpeech::jsSpeaking: return      i18n("Speaking");
         case KSpeech::jsPaused: return        i18n("Paused");
-        case KSpeech::jsFinished: return      i18n("Finished");
-        default: return                       i18n("Unknown");
+        case KSpeech::jsFinished: return      i18nc("Finished the job", "Finished");
+        default: return                       i18nc("State is unknown", "Unknown");
     }
 }
 
@@ -279,9 +277,13 @@ void KttsMgrTray::speakClipboardSelected()
     {
         QString error;
         if (KToolInvocation::startServiceByDesktopName("kttsd", QString(), &error) != 0)
+	{
             kError() << "Starting KTTSD failed with message " << error << endl;
+	    return; 
+	}
     }
-    m_kspeech->sayClipboard();
+    if( isKttsdRunning() ) 
+       m_kspeech->sayClipboard();
 }
 
 void KttsMgrTray::aboutSelected()
@@ -350,6 +352,7 @@ bool KttsMgrTray::isKttsdRunning()
             if (args->isSet("autoexit"))
                 connect(m_kspeech, SIGNAL(jobStateChanged(const QString&, int, int)),
                     this, SLOT(jobStateChanged(const QString&, int, int)));
+	    args->clear();
         }
     } else {
         delete m_kspeech;
