@@ -1,7 +1,8 @@
 /***************************************************** vim:set ts=4 sw=4 sts=4:
   Configuration for the Command Plug in
   -------------------
-  Copyright : (C) 2002,2004 by Gunnar Schmi Dt and Gary Cramblitt
+  Copyright : (C) 2002 by Gunnar Schmi Dt <kmouth@schmi-dt.de>
+  Copyright : (C) 2004 by Gary Cramblitt <garycramblitt@comcast.net>
   -------------------
   Original author: Gunnar Schmi Dt <kmouth@schmi-dt.de>
   Current Maintainer: Gary Cramblitt <garycramblitt@comcast.net>
@@ -11,12 +12,13 @@
  *                                                                         *
  *   This program is free software; you can redistribute it and/or modify  *
  *   it under the terms of the GNU General Public License as published by  *
- *   the Free Software Foundation; version 2 of the License.               *
+ *   the Free Software Foundation; either version 2 of the License, or     *
+ *   (at your option) any later version.                                   *
  *                                                                         *
  ***************************************************************************/
 
-#ifndef _COMMANDCONF_H_
-#define _COMMANDCONF_H_
+#ifndef COMMANDCONF_H
+#define COMMANDCONF_H
 
 // Qt includes.
 
@@ -114,4 +116,4 @@ class CommandConf : public PlugInConf, public Ui::CommandConfWidget {
         // Codec list.
         QStringList m_codecList;
 };
-#endif      // _COMMANDCONF_H_
+#endif      // COMMANDCONF_H
