@@ -205,7 +205,7 @@ QString FestivalIntConf::getTalkerCode()
     QString exePath = realFilePath(festivalPath->url().path());
     if (exePath.isEmpty()) return QString();
     if (getLocation(exePath).isEmpty()) return QString();
-    if (m_voiceList.count() == 0) return QString();
+    if (m_voiceList.isEmpty()) return QString();
     QString normalTalkerCode;
     voiceStruct voiceTemp = m_voiceList[selectVoiceCombo->currentIndex()];
     // Determine volume attribute.  soft < 75% <= medium <= 125% < loud.
@@ -302,7 +302,7 @@ void FestivalIntConf::setDefaultVoice(int currentVoiceIndex)
         {
             for(index = 0 ; index < m_voiceList.count(); ++index)
             {
-                if (m_voiceList[index].name != i18n("Unknown"))
+                if (m_voiceList[index].name != i18nc("The voice is unknown", "Unknown"))
                 {
                     found = true;
                     break;
@@ -510,7 +510,7 @@ void FestivalIntConf::scanVoices()
             {
                 voiceStruct voiceTemp;
                 voiceTemp.code = code;
-                voiceTemp.name = i18n("Unknown");
+                voiceTemp.name = i18nc("The voice is unknown", "Unknown");
                 voiceTemp.languageCode = m_languageCode;
                 voiceTemp.codecName = "ISO 8858-1";
                 voiceTemp.gender = "neutral";
@@ -559,6 +559,8 @@ void FestivalIntConf::slotTest_clicked()
     kDebug() << "FestivalIntConf::slotTest_clicked: tmpWaveFile = " << tmpWaveFile;
 
     // Get the code for the selected voice.
+    if(selectVoiceCombo->currentIndex() < 0 )
+	    return; //TODO add a messagebox
     QString voiceCode = m_voiceList[selectVoiceCombo->currentIndex()].code;
 
     // Get language code for the selected voice.
